@@ -21,4 +21,4 @@ import paho.mqtt.subscribe as subscribe
 def print_msg(client, userdata, message):
     print("%s : %s" % (message.topic, message.payload))
 
-subscribe.callback(print_msg, "#", hostname="iot.eclipse.org")
+subscribe.callback(print_msg, "#", hostname="mqtt.eclipse.org")
